# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.
"""Invenio-theme-kth."""

from .ext import InvenioThemeKTH

__version__ = "1.1.2"
__all__ = ("__version__", "InvenioThemeKTH")



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.

"""Invenio-Theme-KTH extension."""
from . import config


class InvenioThemeKTH:
    """Invenio-Theme-KTH extension."""

    def __init__(self, app=None):
        """Extension initialization."""
        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""
        self.init_config(app)
        app.extensions["invenio-theme-kth"] = self

    def init_config(self, app):
        """Initialize configuration."""
        # Use theme's base template if theme is installed
        for k in dir(config):
            app.config.setdefault(k, getattr(config, k))



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.

"""JS/CSS Webpack bundles for invenio-theme-kth."""

from invenio_assets.webpack import WebpackThemeBundle

theme = WebpackThemeBundle(
    __name__,
    "assets",
    default="semantic-ui",
    themes={
        "semantic-ui": dict(
            entry={
                "invenio-app-rdm-deposit-override": "./js/invenio_theme_kth/deposit/index.js",
            },
            aliases={
                "@js/invenio_theme_kth": "js/invenio_theme_kth",
            },
        ),
    },
)



"""Custom Registration form."""
# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.

from flask import current_app
from invenio_oauthclient.utils import create_registrationform
from invenio_userprofiles.forms import ProfileForm
from markupsafe import Markup
from werkzeug.local import LocalProxy
from wtforms import BooleanField, FormField, validators

# from flask import current_app, url_for

_security = LocalProxy(lambda: current_app.extensions["security"])


def kth_registration_form(*args, **kwargs):
    """KTH_registration_form."""
    # create a link to a PDF file containing the terms and conditions
    # the PDF file is located in the `static/documents` folder.
    # terms_of_use_url = url_for("static", filename=("documents/KTH-terms-of-use-en.pdf"))
    # terms_of_use_text = f"I confirm that I have read and fully understand the \
    # <a class='pull-right' href='{terms_of_use_url}' target='_blank'>terms and conditions</a>\
    # of KTH Royal Institute of Technology."

    terms_of_use_text = Markup(current_app.config["TERMS_OF_USE_TEXT"])
    current_remote_app = kwargs.get("oauth_remote_app")
    if not current_remote_app:
        # return default just in case something is wrong
        return create_registrationform(*args, **kwargs)
    # optionally, have different registration forms depending on the authentication
    # provider used by the user to login
    elif current_remote_app.name.lower() != "orcid":
        # show this form in case the user logged in with any method but ORCID
        class DefaultRegistrationForm(_security.confirm_register_form):
            """DefaultRegistrationForm."""

            email = None  # remove the email field
            password = None  # remove the password field
            profile = FormField(ProfileForm, separator=".")
            recaptcha = None  # remove the captcha
            submit = None  # remove submit btn, already defined in the template
            terms_of_use = BooleanField(
                terms_of_use_text, [validators.required()]
            )  # add the new field

        return DefaultRegistrationForm(*args, **kwargs)
    else:
        # ORCID does not provide the user e-mail address, it must be input by the user.
        # the email field comes from `confirm_register_form` upper class.
        class OrcidRegistrationForm(_security.confirm_register_form):
            """OrcidRegistrationForm."""

            password = None  # remove the password field
            profile = FormField(ProfileForm, separator=".")
            recaptcha = None  # remove the captcha
            submit = None  # remove submit btn, already defined in the template
            terms_of_use = BooleanField(
                terms_of_use_text, [validators.required()]
            )  # add the new field

        return OrcidRegistrationForm(*args, **kwargs)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.
from flask import Flask

from invenio_theme_kth import InvenioThemeKTH, __version__


def test_version():
    """Test version import."""
    from invenio_theme_kth import __version__

    assert __version__


def test_init():
    """Test extension initialization."""
    app = Flask("testapp")
    ext = InvenioThemeKTH(app)
    assert "InvenioThemeKTH" not in app.extensions
    ext.init_app(app)
    assert "invenio-theme-kth" in app.extensions



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.

"""Additional views."""
from flask import Blueprint


def create_blueprint(app):
    """Register blueprint routes on app."""
    blueprint = Blueprint(
        "invenio_theme_kth",
        __name__,
        template_folder="./templates",
        static_folder="static",
    )

    return blueprint



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.
from .utils.registration_form import kth_registration_form

# Invenio-Theme
"""Invenio-Theme config."""
# =============
# See https://invenio-theme.readthedocs.io/en/latest/configuration.html


APP_THEME = ["semantic-ui"]
"""The application theme to use."""


APP_RDM_DEPOSIT_FORM_TEMPLATE = "invenio_app_rdm/records/deposit_override.html"
"""Deposit form page template override."""

TERMS_OF_USE_TEXT = "I confirm that I have read and fully understand the \
<a class='pull-right' href='https://www.kth.se/social/terms/' target='_blank'>terms and conditions</a> \
of KTH Royal Institute of Technology."
"""Signup terms and agreement Checkbox label text"""

OAUTHCLIENT_SIGNUP_FORM = kth_registration_form
"""user registration terms of use checkbox."""



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.

from setuptools import setup

setup()
